@@ -137,6 +137,7 @@ mafw_lastfm_scrobbler_init (MafwLastfmScrobbler *scrobbler)
 
   priv->username = NULL;
   priv->md5password = NULL;
+  /* priv->hard_failure_counter = 0; */
 
   priv->status = MAFW_LASTFM_SCROBBLER_NEED_HANDSHAKE;
 }
@@ -200,6 +201,17 @@ mafw_lastfm_scrobbler_scrobbling_failed (MafwLastfmScrobbler *scrobbler)
   mafw_lastfm_scrobbler_defer_handshake (scrobbler);
 }
 
+/* static void */
+/* mafw_lastfm_scrobbler_hard_failure (MafwLastfmScrobbler *scrobbler) */
+/* { */
+/*   scrobbler->priv->hard_failure_counter++; */
+
+/*   if (scrobbler->priv->hard_failure_counter >= 3) { */
+/*     scrobbler->priv->hard_failure_counter = 0; */
+/*     mafw_lastfm_scrobbler_defer_handshake (scrobbler); */
+/*   } */
+/* } */
+
 static void
 scrobble_cb (SoupSession *session,
              SoupMessage *message,
@@ -207,7 +219,7 @@ scrobble_cb (SoupSession *session,
 {
   if (SOUP_STATUS_IS_SUCCESSFUL (message->status_code)) {
     g_print ("Scrobble: %s", message->response_body->data);
-    if (strcmp (message->response_body->data, "BADSESSION\n") == 0)
+    if (!g_str_has_prefix (message->response_body->data, "OK"))
       mafw_lastfm_scrobbler_scrobbling_failed (MAFW_LASTFM_SCROBBLER (user_data));
   } else {
     mafw_lastfm_scrobbler_scrobbling_failed (MAFW_LASTFM_SCROBBLER (user_data));
@@ -505,6 +517,8 @@ static gboolean
 retry_queue_message (gpointer userdata)
 {
   MafwLastfmScrobblerPrivate *priv = MAFW_LASTFM_SCROBBLER (userdata)->priv;
+
+  priv->retry_id = 0;
   g_print ("retrying to queue message\n");
   soup_session_queue_message (priv->session,
                               priv->retry_message,
